==> mingw-w64-json-fortran-9.0.2-1.src.tar.zst: json-fortran-9.0.2/pages/releases/index.md <==
title: Official Releases

[TOC]

# Official Releases

This is where to find the documentation corresponding to an official,
tagged release. If you are looking for the most current documentation
of the `master` branch, please head back to the
[main page](|url|/index.html).

## Latest Stable Release

**Documentation:**
[{!.VERSION!}](
https://jacobwilliams.github.io/json-fortran/prev/{!.VERSION!}/index.html)

**Download:**
<https://github.com/jacobwilliams/json-fortran/releases/latest>

## Past Releases

**Note:** There is currently no way to navigate back to the general/master
documentation from the documentation for official releases other than
using the browser's back button. Feel free to bookmark this page, or
the [main project page](|url|/index.html) for convenient navigation.

* [9.0.2](https://jacobwilliams.github.io/json-fortran/prev/9.0.2/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/9.0.2)
* [9.0.1](https://jacobwilliams.github.io/json-fortran/prev/9.0.1/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/9.0.1)
* [9.0.0](https://jacobwilliams.github.io/json-fortran/prev/9.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/9.0.0)
* [8.5.2](https://jacobwilliams.github.io/json-fortran/prev/8.5.2/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.5.2)
* [8.5.1](https://jacobwilliams.github.io/json-fortran/prev/8.5.1/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.5.1)
* [8.5.0](https://jacobwilliams.github.io/json-fortran/prev/8.5.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.5.0)
* [8.4.0](https://jacobwilliams.github.io/json-fortran/prev/8.4.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.4.0)
* [8.3.0](https://jacobwilliams.github.io/json-fortran/prev/8.3.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.3.0)
* [8.2.5](https://jacobwilliams.github.io/json-fortran/prev/8.2.5/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.5)
* [8.2.4](https://jacobwilliams.github.io/json-fortran/prev/8.2.4/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.4)
* [8.2.3](https://jacobwilliams.github.io/json-fortran/prev/8.2.3/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.3)
* [8.2.2](https://jacobwilliams.github.io/json-fortran/prev/8.2.2/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.2)
* [8.2.1](https://jacobwilliams.github.io/json-fortran/prev/8.2.1/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.1)
* [8.2.0](https://jacobwilliams.github.io/json-fortran/prev/8.2.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.0)
* [8.1.0](https://jacobwilliams.github.io/json-fortran/prev/8.1.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.1.0)
* [8.0.0](https://jacobwilliams.github.io/json-fortran/prev/8.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.0.0)
* [7.1.0](https://jacobwilliams.github.io/json-fortran/prev/7.1.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/7.1.0)
* [7.0.0](https://jacobwilliams.github.io/json-fortran/prev/7.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/7.0.0)
* [6.11.0](https://jacobwilliams.github.io/json-fortran/prev/6.11.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.11.0)
* [6.10.0](https://jacobwilliams.github.io/json-fortran/prev/6.10.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.10.0)
* [6.9.0](https://jacobwilliams.github.io/json-fortran/prev/6.9.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.9.0)
* [6.8.0](https://jacobwilliams.github.io/json-fortran/prev/6.8.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.8.0)
* [6.7.0](https://jacobwilliams.github.io/json-fortran/prev/6.7.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.7.0)
* [6.6.0](https://jacobwilliams.github.io/json-fortran/prev/6.6.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.6.0)
* [6.5.0](https://jacobwilliams.github.io/json-fortran/prev/6.5.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.5.0)
* [6.4.0](https://jacobwilliams.github.io/json-fortran/prev/6.4.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.4.0)
* [6.3.0](https://jacobwilliams.github.io/json-fortran/prev/6.3.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.3.0)
* [6.2.0](https://jacobwilliams.github.io/json-fortran/prev/6.2.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.2.0)
* [6.1.0](https://jacobwilliams.github.io/json-fortran/prev/6.1.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.1.0)
* [6.0.0](https://jacobwilliams.github.io/json-fortran/prev/6.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.0.0)
* [5.3.0](https://jacobwilliams.github.io/json-fortran/prev/5.3.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.3.0)
* [5.2.0](https://jacobwilliams.github.io/json-fortran/prev/5.2.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.2.0)
* [5.1.0](https://jacobwilliams.github.io/json-fortran/prev/5.1.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.1.0)
* [5.0.2](https://jacobwilliams.github.io/json-fortran/prev/5.0.2/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.0.2)
* [5.0.1](https://jacobwilliams.github.io/json-fortran/prev/5.0.1/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.0.1)
* [5.0.0](https://jacobwilliams.github.io/json-fortran/prev/5.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.0.0)
* [4.3.0](https://jacobwilliams.github.io/json-fortran/prev/4.3.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.3.0)
* [4.2.0](https://jacobwilliams.github.io/json-fortran/prev/4.2.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.2.0)
* [4.1.1](https://jacobwilliams.github.io/json-fortran/prev/4.1.1/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.1.1)
* [4.1.0](https://jacobwilliams.github.io/json-fortran/prev/4.1.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.1.0)
* [4.0.0](https://jacobwilliams.github.io/json-fortran/prev/4.0.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.0.0)
* [3.1.0](https://jacobwilliams.github.io/json-fortran/prev/3.1.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/3.1.0)
* [3.0.0](https://jacobwilliams.github.io/json-fortran/prev/3.0.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/3.0.0)
* [2.0.0](https://jacobwilliams.github.io/json-fortran/prev/2.0.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/2.0.0)
* [1.0.0](https://jacobwilliams.github.io/json-fortran/prev/1.0.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/1.0.0)

# Development Version

Documentation for the latest development version may be found at
<https://jacobwilliams.github.io/json-fortran/prev/{!.VERSION!}/index.html>
or generated locally using the
[build.sh](|url|/page/development-resources/build.sh.html) build
script.

# Changes Between Releases

Included below is the changelog--a list of significant changes
implemented between each release.

{!CHANGELOG.md!}

==> mingw-w64-json-fortran-9.0.3-1.src.tar.zst: json-fortran-9.0.3/pages/releases/index.md <==
title: Official Releases

[TOC]

# Official Releases

This is where to find the documentation corresponding to an official,
tagged release. If you are looking for the most current documentation
of the `master` branch, please head back to the
[main page](|url|/index.html).

## Latest Stable Release

**Documentation:**
[{!.VERSION!}](
https://jacobwilliams.github.io/json-fortran/prev/{!.VERSION!}/index.html)

**Download:**
<https://github.com/jacobwilliams/json-fortran/releases/latest>

## Past Releases

**Note:** There is currently no way to navigate back to the general/master
documentation from the documentation for official releases other than
using the browser's back button. Feel free to bookmark this page, or
the [main project page](|url|/index.html) for convenient navigation.

* [9.0.3](https://jacobwilliams.github.io/json-fortran/prev/9.0.3/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/9.0.3)
* [9.0.2](https://jacobwilliams.github.io/json-fortran/prev/9.0.2/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/9.0.2)
* [9.0.1](https://jacobwilliams.github.io/json-fortran/prev/9.0.1/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/9.0.1)
* [9.0.0](https://jacobwilliams.github.io/json-fortran/prev/9.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/9.0.0)
* [8.5.2](https://jacobwilliams.github.io/json-fortran/prev/8.5.2/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.5.2)
* [8.5.1](https://jacobwilliams.github.io/json-fortran/prev/8.5.1/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.5.1)
* [8.5.0](https://jacobwilliams.github.io/json-fortran/prev/8.5.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.5.0)
* [8.4.0](https://jacobwilliams.github.io/json-fortran/prev/8.4.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.4.0)
* [8.3.0](https://jacobwilliams.github.io/json-fortran/prev/8.3.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.3.0)
* [8.2.5](https://jacobwilliams.github.io/json-fortran/prev/8.2.5/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.5)
* [8.2.4](https://jacobwilliams.github.io/json-fortran/prev/8.2.4/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.4)
* [8.2.3](https://jacobwilliams.github.io/json-fortran/prev/8.2.3/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.3)
* [8.2.2](https://jacobwilliams.github.io/json-fortran/prev/8.2.2/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.2)
* [8.2.1](https://jacobwilliams.github.io/json-fortran/prev/8.2.1/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.1)
* [8.2.0](https://jacobwilliams.github.io/json-fortran/prev/8.2.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.2.0)
* [8.1.0](https://jacobwilliams.github.io/json-fortran/prev/8.1.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.1.0)
* [8.0.0](https://jacobwilliams.github.io/json-fortran/prev/8.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/8.0.0)
* [7.1.0](https://jacobwilliams.github.io/json-fortran/prev/7.1.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/7.1.0)
* [7.0.0](https://jacobwilliams.github.io/json-fortran/prev/7.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/7.0.0)
* [6.11.0](https://jacobwilliams.github.io/json-fortran/prev/6.11.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.11.0)
* [6.10.0](https://jacobwilliams.github.io/json-fortran/prev/6.10.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.10.0)
* [6.9.0](https://jacobwilliams.github.io/json-fortran/prev/6.9.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.9.0)
* [6.8.0](https://jacobwilliams.github.io/json-fortran/prev/6.8.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.8.0)
* [6.7.0](https://jacobwilliams.github.io/json-fortran/prev/6.7.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.7.0)
* [6.6.0](https://jacobwilliams.github.io/json-fortran/prev/6.6.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.6.0)
* [6.5.0](https://jacobwilliams.github.io/json-fortran/prev/6.5.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.5.0)
* [6.4.0](https://jacobwilliams.github.io/json-fortran/prev/6.4.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.4.0)
* [6.3.0](https://jacobwilliams.github.io/json-fortran/prev/6.3.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.3.0)
* [6.2.0](https://jacobwilliams.github.io/json-fortran/prev/6.2.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.2.0)
* [6.1.0](https://jacobwilliams.github.io/json-fortran/prev/6.1.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.1.0)
* [6.0.0](https://jacobwilliams.github.io/json-fortran/prev/6.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/6.0.0)
* [5.3.0](https://jacobwilliams.github.io/json-fortran/prev/5.3.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.3.0)
* [5.2.0](https://jacobwilliams.github.io/json-fortran/prev/5.2.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.2.0)
* [5.1.0](https://jacobwilliams.github.io/json-fortran/prev/5.1.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.1.0)
* [5.0.2](https://jacobwilliams.github.io/json-fortran/prev/5.0.2/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.0.2)
* [5.0.1](https://jacobwilliams.github.io/json-fortran/prev/5.0.1/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.0.1)
* [5.0.0](https://jacobwilliams.github.io/json-fortran/prev/5.0.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/5.0.0)
* [4.3.0](https://jacobwilliams.github.io/json-fortran/prev/4.3.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.3.0)
* [4.2.0](https://jacobwilliams.github.io/json-fortran/prev/4.2.0/index.html)
   ([FORD](https://github.com/Fortran-FOSS-Programmers/ford) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.2.0)
* [4.1.1](https://jacobwilliams.github.io/json-fortran/prev/4.1.1/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.1.1)
* [4.1.0](https://jacobwilliams.github.io/json-fortran/prev/4.1.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.1.0)
* [4.0.0](https://jacobwilliams.github.io/json-fortran/prev/4.0.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/4.0.0)
* [3.1.0](https://jacobwilliams.github.io/json-fortran/prev/3.1.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/3.1.0)
* [3.0.0](https://jacobwilliams.github.io/json-fortran/prev/3.0.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/3.0.0)
* [2.0.0](https://jacobwilliams.github.io/json-fortran/prev/2.0.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/2.0.0)
* [1.0.0](https://jacobwilliams.github.io/json-fortran/prev/1.0.0/index.html)
   ([ROBODoc](https://github.com/gumpu/ROBODoc) generated documentation)
    - [Download](https://github.com/jacobwilliams/json-fortran/releases/tag/1.0.0)

# Development Version

Documentation for the latest development version may be found at
<https://jacobwilliams.github.io/json-fortran/prev/{!.VERSION!}/index.html>
or generated locally using the
[build.sh](|url|/page/development-resources/build.sh.html) build
script.

# Changes Between Releases

Included below is the changelog--a list of significant changes
implemented between each release.

{!CHANGELOG.md!}
